
# FullCalendar RRule Plugin

A connector to the RRule library, for recurring events

[View the docs &raquo;](https://fullcalendar.io/docs/rrule-plugin)

This package was created from the [FullCalendar monorepo &raquo;](https://github.com/fullcalendar/fullcalendar)
